searchNodes=[{"type":"module","title":"TimeQueue","doc":"Implements a timers queue based on a list of maps. The queue can be encoded as JSON. The performance will be worse for large queues in regard to the previous gb_trees based implementation, although the difference is negligible for small queues (&lt;= 1000 entries). All map keys are shrinked to a single letter as this queue is intended to be encoded and published to HTTP clients over the wire, mutiple times. The queue keys are a map composed of the timestamp ( t ) of an event and an unique integer ( u ). No erlang timers or processes are used, as the queue is only a data structure. The advantage is that the queue can be persisted on storage and keeps working after restarting the runtime. The queue maintain its own list of unique integers to avoir relying on BEAM unique integers as they are reset on VM restarts. The main drawback of a functional queue is that the queue entries must be manually checked for expired timers.","ref":"TimeQueue.html"},{"type":"function","title":"TimeQueue.delete/2","doc":"Deletes an event from the queue and returns the new queue. It accepts a time reference or a full event. When an event is given, its time reference will be used to find the event to delete, meaning the queue event will be deleted even if the value of the passed event was tampered. The function does not fail if the event cannot be found and simply returns the queue as-is.","ref":"TimeQueue.html#delete/2"},{"type":"function","title":"TimeQueue.delete_val/2","doc":"Deletes all entries from the queue whose values are equal to unwanted .","ref":"TimeQueue.html#delete_val/2"},{"type":"function","title":"TimeQueue.enqueue/3","doc":"Adds a new event to the queue with a TTL and the current system time as now/0 . See enqueue/4 .","ref":"TimeQueue.html#enqueue/3"},{"type":"function","title":"TimeQueue.enqueue/4","doc":"Adds a new event to the queue with a TTL relative to the given timestamp in milliseconds. Returns {:ok, tref, new_queue} where tref is a timer reference.","ref":"TimeQueue.html#enqueue/4"},{"type":"function","title":"TimeQueue.enqueue_abs/3","doc":"Adds a new event to the queue with an absolute timestamp. Returns {:ok, tref, new_queue} where tref is a timer reference.","ref":"TimeQueue.html#enqueue_abs/3"},{"type":"function","title":"TimeQueue.filter/2","doc":"Returns a new queue with entries for whom the given callback returned a truthy value. Use filter_val/2 to filter only using values.","ref":"TimeQueue.html#filter/2"},{"type":"function","title":"TimeQueue.filter_val/2","doc":"Returns a new queue with entries for whom the given callback returned a truthy value. Unlinke filter/2 , the callback is only passed the event value.","ref":"TimeQueue.html#filter_val/2"},{"type":"function","title":"TimeQueue.new/0","doc":"Creates an empty time queue. iex&gt; tq = TimeQueue . new ( ) iex&gt; TimeQueue . peek_event ( tq ) :empty","ref":"TimeQueue.html#new/0"},{"type":"function","title":"TimeQueue.now/0","doc":"This function is used internally to determine the current time when using functions enqueue/3 , pop/1 , pop_event/1 and peek_event/1 . It is a simple alias to :erlang.system_time(:millisecond) . TimeQueue does not use monotonic time since it already manages its own unique identifiers for queue entries.","ref":"TimeQueue.html#now/0"},{"type":"function","title":"TimeQueue.peek/1","doc":"Returns the next value of the queue or a delay in milliseconds before the next value. See peek/2 .","ref":"TimeQueue.html#peek/1"},{"type":"function","title":"TimeQueue.peek/2","doc":"Returns the next value of the queue, or a delay, according to the given current time in milliseconds. Just like pop/2 vs. pop_event/2 , peek wil only return {:ok, value} when a timeout is reached whereas peek_event will return {:ok, event} .","ref":"TimeQueue.html#peek/2"},{"type":"function","title":"TimeQueue.peek_event/1","doc":"Returns the next event of the queue or a delay in milliseconds before the next value. event values can be retrieved with TimeQueue.value/1 . See peek_event/2 .","ref":"TimeQueue.html#peek_event/1"},{"type":"function","title":"TimeQueue.peek_event/2","doc":"Returns the next event of the queue according to the given current time in milliseconds. Possible return values are: :empty {:ok, event} if the timestamp of the first event is &lt;= to the given current time. {:delay, tref, ms} if the timestamp of the first event is &gt; to the given current time. The remaining amount of milliseconds is returned. Example iex&gt; { :ok , tref , tq } = TimeQueue . new ( ) |&gt; TimeQueue . enqueue ( 100 , :hello , _now = 0 ) iex&gt; { :delay , ^ tref , 80 } = TimeQueue . peek_event ( tq , _now = 20 ) iex&gt; { :ok , _ } = TimeQueue . peek_event ( tq , _now = 100 )","ref":"TimeQueue.html#peek_event/2"},{"type":"function","title":"TimeQueue.pop/1","doc":"Extracts the next event in the queue or returns a delay. See pop/2 .","ref":"TimeQueue.html#pop/1"},{"type":"function","title":"TimeQueue.pop/2","doc":"Extracts the next event in the queue according to the given current time in milliseconds. Much like pop_event/2 but the tuple returned when an event time is reached (returns with :ok ) success will only contain the value inserted in the queue. Possible return values are: :empty {:ok, value, new_queue} if the timestamp of the first event is &lt;= to the given current time. The event is deleted from new_queue . {:delay, tref, ms} if the timestamp of the first event is &gt; to the given current time. The remaining amount of milliseconds is returned. Example iex&gt; { :ok , tref , tq } = TimeQueue . new ( ) |&gt; TimeQueue . enqueue ( 100 , :hello , _now = 0 ) iex&gt; { :delay , ^ tref , 80 } = TimeQueue . pop ( tq , _now = 20 ) iex&gt; { :ok , value , _ } = TimeQueue . pop ( tq , _now = 100 ) iex&gt; value :hello","ref":"TimeQueue.html#pop/2"},{"type":"function","title":"TimeQueue.pop_event/1","doc":"Extracts the next event in the queue with the current system time as now/0 . See pop_event/2 .","ref":"TimeQueue.html#pop_event/1"},{"type":"function","title":"TimeQueue.pop_event/2","doc":"Extracts the next event in the queue according to the given current time in milliseconds. Possible return values are: :empty {:ok, event, new_queue} if the timestamp of the first event is &lt;= to the given current time. The event is deleted from new_queue . {:delay, tref, ms} if the timestamp of the first event is &gt; to the given current time. The remaining amount of milliseconds is returned. Example iex&gt; { :ok , tref , tq } = TimeQueue . new ( ) |&gt; TimeQueue . enqueue ( 100 , :hello , _now = 0 ) iex&gt; { :delay , ^ tref , 80 } = TimeQueue . pop_event ( tq , _now = 20 ) iex&gt; { :ok , event , _ } = TimeQueue . pop_event ( tq , _now = 100 ) iex&gt; TimeQueue . value ( event ) :hello","ref":"TimeQueue.html#pop_event/2"},{"type":"function","title":"TimeQueue.size/1","doc":"Returns the number of entries in the queue.","ref":"TimeQueue.html#size/1"},{"type":"function","title":"TimeQueue.timeout/1","doc":"Returns the time to next event. Same as timeout(tq, :infinity, now()) . See timeout/3 .","ref":"TimeQueue.html#timeout/1"},{"type":"function","title":"TimeQueue.timeout/2","doc":"Returns the time to next event. Accepts either the current time or an atom to return when the queue is empty. If an integer is given, it will has the same result as timeout(tq, :infinity, integer) . If an atom is given, it will has the same result as timeout(tq, atom, now()) . See timeout/3 .","ref":"TimeQueue.html#timeout/2"},{"type":"function","title":"TimeQueue.timeout/3","doc":"Provides a GenServer compatible timeout from the queue, giving the time to the next event. Accepts the current time as a third argument or will default to the current system time. Returns: if_empty when the queue is empty. A common value in that case is either :infinity or :hibernate . 0 when there the next event time has been reached. The delay to the next event otherwise. For instance, when used in a GenServer , this function can tell when to automatically wakeup the process. def handle_call ( request , _from , state ) do state = do_stuff ( state , request ) timeout = TimeQueue . timeout ( state . time_queue ) { :reply , :ok , state , timeout } end By default, timeout/1 and timeout/2 (if called with an integer for the current time) will return :infinity if the queue if empty. But you may pass :hibernate as the second argument for timeout/2 or timeout/3 to return :hibernate instead. Note that any other atom than :infinity or :hibernate will be returned as-is if as well if the queue is empty.","ref":"TimeQueue.html#timeout/3"},{"type":"function","title":"TimeQueue.timestamp/1","doc":"Returns the absolute timestamp a queue event is scheduled for. iex&gt; tq = TimeQueue . new ( ) iex&gt; { :ok , _ , tq } = TimeQueue . enqueue_abs ( tq , 1234 , :my_value ) iex&gt; { :ok , event } = TimeQueue . peek_event ( tq ) iex&gt; TimeQueue . timestamp ( event ) 1234","ref":"TimeQueue.html#timestamp/1"},{"type":"function","title":"TimeQueue.tref/1","doc":"Returns the time reference of a queue event. This reference is used as a key to identify a unique event. iex&gt; tq = TimeQueue . new ( ) iex&gt; { :ok , tref , tq } = TimeQueue . enqueue ( tq , 10 , :my_value ) iex&gt; Process . sleep ( 10 ) iex&gt; { :ok , event } = TimeQueue . peek_event ( tq ) iex&gt; tref == TimeQueue . tref ( event ) true","ref":"TimeQueue.html#tref/1"},{"type":"function","title":"TimeQueue.value/1","doc":"Returns the value of a queue event. iex&gt; tq = TimeQueue . new ( ) iex&gt; { :ok , _ , tq } = TimeQueue . enqueue ( tq , 10 , :my_value ) iex&gt; Process . sleep ( 10 ) iex&gt; { :ok , event } = TimeQueue . peek_event ( tq ) iex&gt; TimeQueue . value ( event ) :my_value","ref":"TimeQueue.html#value/1"},{"type":"opaque","title":"TimeQueue.event/0","doc":"","ref":"TimeQueue.html#t:event/0"},{"type":"type","title":"TimeQueue.event_value/0","doc":"","ref":"TimeQueue.html#t:event_value/0"},{"type":"opaque","title":"TimeQueue.t/0","doc":"","ref":"TimeQueue.html#t:t/0"},{"type":"type","title":"TimeQueue.timespec/0","doc":"","ref":"TimeQueue.html#t:timespec/0"},{"type":"type","title":"TimeQueue.timespec_unit/0","doc":"","ref":"TimeQueue.html#t:timespec_unit/0"},{"type":"type","title":"TimeQueue.timestamp_ms/0","doc":"","ref":"TimeQueue.html#t:timestamp_ms/0"},{"type":"opaque","title":"TimeQueue.tref/0","doc":"","ref":"TimeQueue.html#t:tref/0"},{"type":"type","title":"TimeQueue.ttl/0","doc":"","ref":"TimeQueue.html#t:ttl/0"},{"type":"module","title":"TimeQueue.GbTrees","doc":"Implements a timers queue based on gb_trees . The queue keys are a two-tuple composed of the timestamp of an event and an unique integer. No erlang timers or processes are used, as the queue is only a data structure. The advantage is that the queue can be persisted on storage and keep working after restarting the runtime. The queue maintain its own list of unique integers to avoir relying on BEAM unique integers as they are reset on restart. The main drawback is that the queue entries must be manually checked for expired timers.","ref":"TimeQueue.GbTrees.html"},{"type":"function","title":"TimeQueue.GbTrees.delete/2","doc":"Deletes an event from the queue and returns the new queue. It accepts a time reference or a full event. When an event is given, its time reference will be used to find the event to delete, meaning the queue event will be deleted even if the value of the passed event was tampered. The function does not fail if the event cannot be found and simply returns the queue as-is.","ref":"TimeQueue.GbTrees.html#delete/2"},{"type":"function","title":"TimeQueue.GbTrees.delete_val/2","doc":"Deletes all entries from the queue whose values are equal to unwanted . This function is slow with gb_trees , see filter/2 .","ref":"TimeQueue.GbTrees.html#delete_val/2"},{"type":"function","title":"TimeQueue.GbTrees.enqueue/3","doc":"Adds a new event to the queue with a TTL and the current system time as now/0 . See enqueue/4 .","ref":"TimeQueue.GbTrees.html#enqueue/3"},{"type":"function","title":"TimeQueue.GbTrees.enqueue/4","doc":"Adds a new event to the queue with a TTL relative to the given timestamp in milliseconds. Returns {:ok, tref, new_queue} where tref is a timer reference.","ref":"TimeQueue.GbTrees.html#enqueue/4"},{"type":"function","title":"TimeQueue.GbTrees.enqueue_abs/3","doc":"Adds a new event to the queue with an absolute timestamp. Returns {:ok, tref, new_queue} where tref is a timer reference.","ref":"TimeQueue.GbTrees.html#enqueue_abs/3"},{"type":"function","title":"TimeQueue.GbTrees.filter/2","doc":"Returns a new queue with entries for whom the given callback returned a truthy value. With the gb trees implementation, this operation is _very expensive as we convert the tree to and ordered list, filter the list, and convert back to a tree.","ref":"TimeQueue.GbTrees.html#filter/2"},{"type":"function","title":"TimeQueue.GbTrees.filter_val/2","doc":"Returns a new queue with entries for whom the given callback returned a truthy value. Unlinke filter/2 , the callback is only passed the event value. This function is slow with gb_trees , see filter/2 .","ref":"TimeQueue.GbTrees.html#filter_val/2"},{"type":"function","title":"TimeQueue.GbTrees.new/0","doc":"Creates an empty time queue. iex&gt; tq = TimeQueue.GbTrees . new ( ) iex&gt; TimeQueue.GbTrees . peek_event ( tq ) :empty","ref":"TimeQueue.GbTrees.html#new/0"},{"type":"function","title":"TimeQueue.GbTrees.peek/1","doc":"Returns the next value of the queue or a delay in milliseconds before the next value. See peek/2 .","ref":"TimeQueue.GbTrees.html#peek/1"},{"type":"function","title":"TimeQueue.GbTrees.peek/2","doc":"Returns the next value of the queue, or a delay, according to the given current time in milliseconds. Just like pop/2 vs. pop_event/2 , peek wil only return {:ok, value} when a timeout is reached whereas peek_event will return {:ok, event} .","ref":"TimeQueue.GbTrees.html#peek/2"},{"type":"function","title":"TimeQueue.GbTrees.peek_event/1","doc":"Returns the next event of the queue or a delay in milliseconds before the next value. event values can be retrieved with TimeQueue.GbTrees.value/1 . See peek_event/2 .","ref":"TimeQueue.GbTrees.html#peek_event/1"},{"type":"function","title":"TimeQueue.GbTrees.peek_event/2","doc":"Returns the next event of the queue according to the given current time in milliseconds. Possible return values are: :empty {:ok, event} if the timestamp of the first event is &lt;= to the given current time. {:delay, tref, ms} if the timestamp of the first event is &gt; to the given current time. The remaining amount of milliseconds is returned. Example iex&gt; { :ok , tref , tq } = TimeQueue.GbTrees . new ( ) |&gt; TimeQueue.GbTrees . enqueue ( 100 , :hello , _now = 0 ) iex&gt; { :delay , ^ tref , 80 } = TimeQueue.GbTrees . peek_event ( tq , _now = 20 ) iex&gt; { :ok , _ } = TimeQueue.GbTrees . peek_event ( tq , _now = 100 )","ref":"TimeQueue.GbTrees.html#peek_event/2"},{"type":"function","title":"TimeQueue.GbTrees.pop/1","doc":"Extracts the next event in the queue or returns a delay. See pop/2 .","ref":"TimeQueue.GbTrees.html#pop/1"},{"type":"function","title":"TimeQueue.GbTrees.pop/2","doc":"Extracts the next event in the queue according to the given current time in milliseconds. Much like pop_event/2 but the tuple returned when an event time is reached (returns with :ok ) success will only contain the value inserted in the queue. Possible return values are: :empty {:ok, value, new_queue} if the timestamp of the first event is &lt;= to the given current time. The event is deleted from new_queue . {:delay, tref, ms} if the timestamp of the first event is &gt; to the given current time. The remaining amount of milliseconds is returned. Example iex&gt; { :ok , tref , tq } = TimeQueue.GbTrees . new ( ) |&gt; TimeQueue.GbTrees . enqueue ( 100 , :hello , _now = 0 ) iex&gt; { :delay , ^ tref , 80 } = TimeQueue.GbTrees . pop ( tq , _now = 20 ) iex&gt; { :ok , value , _ } = TimeQueue.GbTrees . pop ( tq , _now = 100 ) iex&gt; value :hello","ref":"TimeQueue.GbTrees.html#pop/2"},{"type":"function","title":"TimeQueue.GbTrees.pop_event/1","doc":"Extracts the next event of the queue with the current system time as now/0 . See pop_event/2 .","ref":"TimeQueue.GbTrees.html#pop_event/1"},{"type":"function","title":"TimeQueue.GbTrees.pop_event/2","doc":"Extracts the next event of the queue according to the given current time in milliseconds. Possible return values are: :empty {:ok, event, new_queue} if the timestamp of the first event is &lt;= to the given current time. The event is deleted from new_queue . {:delay, tref, ms} if the timestamp of the first event is &gt; to the given current time. The remaining amount of milliseconds is returned. Example iex&gt; { :ok , tref , tq } = TimeQueue.GbTrees . new ( ) |&gt; TimeQueue.GbTrees . enqueue ( 100 , :hello , _now = 0 ) iex&gt; { :delay , ^ tref , 80 } = TimeQueue.GbTrees . pop_event ( tq , _now = 20 ) iex&gt; { :ok , _ , _ } = TimeQueue.GbTrees . pop_event ( tq , _now = 100 )","ref":"TimeQueue.GbTrees.html#pop_event/2"},{"type":"function","title":"TimeQueue.GbTrees.size/1","doc":"Returns the number of entries in the queue.","ref":"TimeQueue.GbTrees.html#size/1"},{"type":"function","title":"TimeQueue.GbTrees.timeout/1","doc":"Returns the time to next event. Same as timeout(tq, :infinity, now()) . See timeout/3 .","ref":"TimeQueue.GbTrees.html#timeout/1"},{"type":"function","title":"TimeQueue.GbTrees.timeout/2","doc":"Returns the time to next event. Accepts either the current time or an atom to return when the queue is empty. If an integer is given, it will has the same result as timeout(tq, :infinity, integer) . If an atom is given, it will has the same result as timeout(tq, atom, now()) . See timeout/3 .","ref":"TimeQueue.GbTrees.html#timeout/2"},{"type":"function","title":"TimeQueue.GbTrees.timeout/3","doc":"Provides a GenServer compatible timeout from the queue, giving the time to the next event. Accepts the current time as a third argument or will default to the current system time. Returns: if_empty when the queue is empty. A common value in that case is either :infinity or :hibernate . 0 when there the next event time has been reached. The delay to the next event otherwise. For instance, when used in a GenServer , this function can tell when to automatically wakeup the process. def handle_call ( request , _from , state ) do state = do_stuff ( state , request ) timeout = TimeQueue.GbTrees . timeout ( state . time_queue ) { :reply , :ok , state , timeout } end By default, timeout/1 and timeout/2 (if called with an integer for the current time) will return :infinity if the queue if empty. But you may pass :hibernate as the second argument for timeout/2 or timeout/3 to return :hibernate instead. Note that any other atom than :infinity or :hibernate will be returned as-is if as well if the queue is empty.","ref":"TimeQueue.GbTrees.html#timeout/3"},{"type":"function","title":"TimeQueue.GbTrees.timestamp/1","doc":"Returns the absolute timestamp a queue event is scheduled for. iex&gt; tq = TimeQueue.GbTrees . new ( ) iex&gt; { :ok , _ , tq } = TimeQueue.GbTrees . enqueue_abs ( tq , 1234 , :my_value ) iex&gt; { :ok , event } = TimeQueue.GbTrees . peek_event ( tq ) iex&gt; TimeQueue.GbTrees . timestamp ( event ) 1234","ref":"TimeQueue.GbTrees.html#timestamp/1"},{"type":"function","title":"TimeQueue.GbTrees.tref/1","doc":"Returns the time reference of a queue event. This reference is used as a key to identify a unique event. iex&gt; tq = TimeQueue.GbTrees . new ( ) iex&gt; { :ok , tref , tq } = TimeQueue.GbTrees . enqueue ( tq , 10 , :my_value ) iex&gt; Process . sleep ( 10 ) iex&gt; { :ok , event } = TimeQueue.GbTrees . peek_event ( tq ) iex&gt; tref == TimeQueue.GbTrees . tref ( event ) true","ref":"TimeQueue.GbTrees.html#tref/1"},{"type":"function","title":"TimeQueue.GbTrees.value/1","doc":"Returns the value of a queue event. iex&gt; tq = TimeQueue.GbTrees . new ( ) iex&gt; { :ok , _ , tq } = TimeQueue.GbTrees . enqueue ( tq , 10 , :my_value ) iex&gt; Process . sleep ( 10 ) iex&gt; { :ok , event } = TimeQueue.GbTrees . peek_event ( tq ) iex&gt; TimeQueue.GbTrees . value ( event ) :my_value","ref":"TimeQueue.GbTrees.html#value/1"},{"type":"opaque","title":"TimeQueue.GbTrees.event/0","doc":"","ref":"TimeQueue.GbTrees.html#t:event/0"},{"type":"type","title":"TimeQueue.GbTrees.event_value/0","doc":"","ref":"TimeQueue.GbTrees.html#t:event_value/0"},{"type":"opaque","title":"TimeQueue.GbTrees.id/0","doc":"","ref":"TimeQueue.GbTrees.html#t:id/0"},{"type":"opaque","title":"TimeQueue.GbTrees.t/0","doc":"","ref":"TimeQueue.GbTrees.html#t:t/0"},{"type":"type","title":"TimeQueue.GbTrees.timespec/0","doc":"","ref":"TimeQueue.GbTrees.html#t:timespec/0"},{"type":"type","title":"TimeQueue.GbTrees.timespec_unit/0","doc":"","ref":"TimeQueue.GbTrees.html#t:timespec_unit/0"},{"type":"type","title":"TimeQueue.GbTrees.timestamp_ms/0","doc":"","ref":"TimeQueue.GbTrees.html#t:timestamp_ms/0"},{"type":"opaque","title":"TimeQueue.GbTrees.tref/0","doc":"","ref":"TimeQueue.GbTrees.html#t:tref/0"},{"type":"type","title":"TimeQueue.GbTrees.ttl/0","doc":"","ref":"TimeQueue.GbTrees.html#t:ttl/0"},{"type":"module","title":"TimeQueue.TimeInterval","doc":"Utility to parse and format time intervals represented as strings. A time interval is formatted as pairs of numbers and units. For instance 1d2h is two pairs and means 1 day and 2 hours. The unit is always lowercase and one of: d for day h for hour m for minute s for second Note that the ms unit is not supported on parsing, but will be returned when formatting an interval (integer or struct) that is smaller than 1 second. There are a couple of rules regarding the format: The order of the pairs is not significant. 1d2h is the same as 2h1d . The addition is supported, i.e. the units are cumulative. 1d1d is the same as 2d . The subtraction is not supported, each pair is absolute and just represent a quantity of milliseconds. But it is possible to prefix the expression with a - , which will make the parser return a negative value. So -1d1h will return a negative number, but 1d-1h or 1d-1d are invalid.","ref":"TimeQueue.TimeInterval.html"},{"type":"function","title":"TimeQueue.TimeInterval.days/1","doc":"Returns the number of milliseconds in n days.","ref":"TimeQueue.TimeInterval.html#days/1"},{"type":"function","title":"TimeQueue.TimeInterval.hours/1","doc":"Returns the number of milliseconds in n hours. Alias for :timer.hours/1 .","ref":"TimeQueue.TimeInterval.html#hours/1"},{"type":"function","title":"TimeQueue.TimeInterval.minutes/1","doc":"Returns the number of milliseconds in n minutes. Alias for :timer.minutes/1 .","ref":"TimeQueue.TimeInterval.html#minutes/1"},{"type":"function","title":"TimeQueue.TimeInterval.parse/1","doc":"Returns a %TimeQueue.TimeInterval{} struct from a time interval string. Examples iex&gt; TimeInterval . parse ( &quot;1d1h&quot; ) { :ok , % TimeQueue.TimeInterval { ms : 90000000 } } iex&gt; TimeInterval . parse ( &quot;some gibberish&quot; ) { :error , { :cannot_parse_interval , &quot;some gibberish&quot; } }","ref":"TimeQueue.TimeInterval.html#parse/1"},{"type":"function","title":"TimeQueue.TimeInterval.parse!/1","doc":"Same as parse/1 but returns the struct directly or raises an ArgumentError . Example iex&gt; TimeInterval . parse! ( &quot;1d1h&quot; ) % TimeQueue.TimeInterval { ms : 90000000 }","ref":"TimeQueue.TimeInterval.html#parse!/1"},{"type":"function","title":"TimeQueue.TimeInterval.seconds/1","doc":"Returns the number of milliseconds in n seconds. Alias for :timer.seconds/1 .","ref":"TimeQueue.TimeInterval.html#seconds/1"},{"type":"function","title":"TimeQueue.TimeInterval.to_ms/1","doc":"Returns the number of milliseconds in the given interval, wrapped in an :ok tuple, or an :error tuple. The interval can be a string or a %TimeQueue.TimeInterval{} struct. For convenience reasons, this function also accepts integers, which are returned as is. Examples iex&gt; TimeInterval . to_ms ( &quot;1d1h&quot; ) { :ok , 90000000 } iex&gt; &quot;1d1h&quot; |&gt; TimeInterval . parse! ( ) |&gt; TimeInterval . to_ms ( ) { :ok , 90000000 } iex&gt; TimeInterval . to_ms ( &quot;some gibberish&quot; ) { :error , { :cannot_parse_interval , &quot;some gibberish&quot; } } iex&gt; TimeInterval . to_ms ( 1234 ) { :ok , 1234 }","ref":"TimeQueue.TimeInterval.html#to_ms/1"},{"type":"function","title":"TimeQueue.TimeInterval.to_ms!/1","doc":"Same as to_ms/1 but returns the number of milliseconds directly or raises an ArgumentError .","ref":"TimeQueue.TimeInterval.html#to_ms!/1"},{"type":"function","title":"TimeQueue.TimeInterval.to_string/1","doc":"Returns the string representation of the given time interval. Note that as this module is intended to work with long durations, the number of remaining milliseconds after having computed the days, hours, minutes and seconds, is discarded. Examples iex&gt; &quot;1d1h&quot; |&gt; TimeInterval . parse! ( ) |&gt; TimeInterval . to_string ( ) &quot;1d1h&quot; iex&gt; &quot;1d1d1d&quot; |&gt; TimeInterval . parse! ( ) |&gt; TimeInterval . to_string ( ) &quot;3d&quot; iex&gt; TimeInterval . to_string ( 90000000 ) &quot;1d1h&quot; iex&gt; TimeInterval . to_string ( 90000123 ) # Discared remaining milliseconds &quot;1d1h&quot; iex&gt; TimeInterval . to_string ( 123 ) # Smaller than 1 second &quot;123ms&quot;","ref":"TimeQueue.TimeInterval.html#to_string/1"},{"type":"function","title":"TimeQueue.TimeInterval.to_string/2","doc":"Returns the string representation with the same rules as in to_string/1 but in long form. Example iex&gt; &quot;1d1h&quot; |&gt; TimeInterval . parse! ( ) |&gt; TimeInterval . to_string ( :verbose ) &quot;1 day 1 hour&quot;","ref":"TimeQueue.TimeInterval.html#to_string/2"},{"type":"type","title":"TimeQueue.TimeInterval.t/0","doc":"","ref":"TimeQueue.TimeInterval.html#t:t/0"},{"type":"extras","title":"TimeQueue","doc":"This library implements a pure functional queue of timers that is persistable as a simple erlang term. No processes or Erlang timers are used.","ref":"readme.html"},{"type":"extras","title":"TimeQueue - Use case","doc":"When you need to attach timers to a persistent data structure (ecto schemas, persistent GenServers, …), for example in a board game. When you need to publish timers over an API (JSON, XML, …).","ref":"readme.html#use-case"},{"type":"extras","title":"TimeQueue - Changelog","doc":"Please see the changelog on Github (master branch) .","ref":"readme.html#changelog"},{"type":"extras","title":"TimeQueue - Installation","doc":"def deps do [ { :time_queue , &quot;~&gt; 0.9&quot; } ] end","ref":"readme.html#installation"},{"type":"extras","title":"TimeQueue - Basic Usage","doc":"tq = TimeQueue . new ( ) { :ok , tref , tq } = TimeQueue . enqueue ( tq , { 500 , :ms } , :myval ) { :delay , ^ tref , _delay } = TimeQueue . peek ( tq ) { :delay , ^ tref , _delay } = TimeQueue . pop ( tq ) Process . sleep ( delay ) # PEEK { :ok , entry } = TimeQueue . peek ( tq ) :myval = TimeQueue . value ( entry ) # POP { :ok , entry , tq } = TimeQueue . pop ( tq ) :myval = TimeQueue . value ( entry ) :empty = TimeQueue . pop ( tq )","ref":"readme.html#basic-usage"}]